# XenGarden
XenGarden, An Object-Oriented Python Middleware for XenAPI.  
![Python version](https://img.shields.io/pypi/pyversions/XenGarden)  

[Discord Community](https://opensource.stella-it.com/discord/)     
  
## Build Status
| Name                      | Status                                                                                                         |
|---------------------------|----------------------------------------------------------------------------------------------------------------|
| Python Script Black Lint  | ![Upload Python Package](https://github.com/Stella-IT/XenGarden/workflows/Upload%20Python%20Package/badge.svg) |
  
## Contributors' Guidelines
Please refer to [CONTRIBUTING.md](CONTRIBUTING.md) for more information.  

## Code of Conduct
This project has adopted Stella IT Opensource Project Code of Conduct.  
Please refer to [CODE_OF_CONDUCT.md](CODE_OF_CONDUCT.md) for more information.  

## License
Distributed under MIT License.  
